@@ -7,6 +7,9 @@ To use this module, set ``HTTPServer.ssl_adapter`` to an instance of
 ``BuiltinSSLAdapter``.
 """
 
+from __future__ import absolute_import, division, print_function
+__metaclass__ = type
+
 try:
     import ssl
 except ImportError:
@@ -20,11 +23,21 @@ except ImportError:
     except ImportError:
         DEFAULT_BUFFER_SIZE = -1
 
+import six
+
 from . import Adapter
 from .. import errors
 from ..makefile import MakeFile
 
 
+if six.PY3:
+    generic_socket_error = OSError
+else:
+    import socket
+    generic_socket_error = socket.error
+    del socket
+
+
 def _assert_ssl_exc_contains(exc, *msgs):
     """Check whether SSL exception contains either of messages provided."""
     if len(msgs) < 1:
@@ -114,6 +127,20 @@ class BuiltinSSLAdapter(Adapter):
                 # The connection can safely be dropped.
                 return EMPTY_RESULT
             raise
+        except generic_socket_error as exc:
+            """It is unclear why exactly this happens.
+
+            It's reproducible only under Python 2 with openssl>1.0 and stdlib
+            ``ssl`` wrapper, and only with CherryPy.
+            So it looks like some healthcheck tries to connect to this socket
+            during startup (from the same process).
+
+
+            Ref: https://github.com/cherrypy/cherrypy/issues/1618
+            """
+            if six.PY2 and exc.args == (0, 'Error'):
+                return EMPTY_RESULT
+            raise
         return s, self.get_environ(s)
 
     # TODO: fill this out more with mod ssl env
